Package: munsell
Type: Package
Title: Utilities for Using Munsell Colours
Version: 0.5.0
Author: Charlotte Wickham <cwickham@gmail.com>
Maintainer: Charlotte Wickham <cwickham@gmail.com>
Description: Provides easy access to, and manipulation of, the Munsell 
    colours. Provides a mapping between Munsell's 
    original notation (e.g. "5R 5/10") and hexadecimal strings suitable 
    for use directly in R graphics. Also provides utilities 
    to explore slices through the Munsell colour tree, to transform 
    Munsell colours and display colour palettes.
Suggests: ggplot2, testthat
Imports: colorspace, methods
License: MIT + file LICENSE
URL: https://cran.r-project.org/package=munsell,
        https://github.com/cwickham/munsell/
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2018-06-11 23:15:15 UTC; wickhamc
Repository: CRAN
Date/Publication: 2018-06-12 04:29:06 UTC
